#!/usr/local/env python
#############################################################################
# Name:         check.py
# Purpose:      Simple test view for Kerberos5 admin adapter functionality
# Maintainer:   Torsten Kurbad
# Copyright:    (c) 2008 iwm-kmrc.de KMRC - Knowledge Media Research Center
# Licence:      GPL
#############################################################################
"""View Class for the Container's Contents view.
"""
from zope.app.pagetemplate.viewpagetemplatefile import ViewPageTemplateFile
from zope.publisher.browser import BrowserView

from kadm5adapter.interfaces import IKAdm5Adapter
from kadm5adapter.interfaces import ICheckKAdm5Adapter


class CheckKAdm5AdapterView(BrowserView):
    """ View for a simple KAdm5Adapter connection test. """
    __used_for__ = IKAdm5Adapter

    def __init__(self, context, request):
        self.context = context
        self.request = request
        self.__parent__ = context
        self.report = []

    def getClientInfo(self):
        """ Returns a dict with connection information. """
        infoDict = {}
        infoDict['client'] = self.context.client
        infoDict['password'] = self.context.password
        infoDict['realm'] = self.context.realm
        return infoDict


    def checkConnection(self):
        """ Test the KAdmin connection. Returns "Success!" or "Failure!" """
        if self.request.get('runDefault', None):
            client = self.context.client
            password = self.context.password
            realm = self.context.realm
            testadapter = ICheckKAdm5Adapter(self.context)
            self._addInfo("<strong>"
                          "Test python connection to Kerberos5 admin server"
                          "</strong>")
            self.report = self.report + testadapter.testConnection(client, password, realm)
            self._addInfo("<strong>Tests done</strong>")
            self._addInfo(" ")
    
            return self.report
        else:
            return ""

    def _addInfo(self, res):
        """ Add traceback info to the report list. """
        self.report.append(res)

    check = ViewPageTemplateFile('check.pt')
