#!/usr/local/env python
#############################################################################
# Name:         check.py
# Purpose:      Simple test for Kerberos5 admin adapter functionality
# Maintainer:   Torsten Kurbad
# Copyright:    (c) 2008 iwm-kmrc.de KMRC - Knowledge Media Research Center
# Licence:      GPL
#############################################################################
"""A KAdm5 Adapter Test Facility
"""
import zope.interface
from zope.interface import implements
from zope.security.proxy import removeSecurityProxy

from kadm5adapter.interfaces import ICheckKAdm5Adapter

class CheckKAdm5Adapter:
    """ A test adapter for to test the connection from Zope to KAdmin. """
    zope.interface.implements(ICheckKAdm5Adapter)

    def __init__(self, context):
        self.context = context
        self.report = []
    
    def testConnection(self, client, password, realm):
        """ Test the KAdmin connection. Returns "Success!" or "Failure!" """
        self.report = []
        adapter = removeSecurityProxy(self.context)
        self.report.append("... start check connection")
        
        try:
            self.report.append("... try connect with:")
            self.report.append("... client principal = %s" % client)
            self.report.append("... realm            = %s" % realm)
            connection = adapter.kconnect(client, password, realm)

            if connection is not None:
                princlist = connection.getPrincipals()
                code = connection.destroy()
                try:
                    princlist = ("%s" % princlist[-3:])
                    princlist = ("[ ... %s" % princlist[1:])
                except:
                    pass
                self.report.append("... <strong>connection OK!</strong>")
                self.report.append("")
                self.report.append("<strong>%s</strong>" % princlist)
            else:
                self.report.append("... <strong>Connection None</strong>")

            return self.report

        except:
            self.report.append("... <strong>Test failed!</strong>")
            return self.report
