#!/usr/local/env python
#############################################################################
# Name:         exceptions.py
# Purpose:      Kerberos5 admin service adapter exceptions
# Maintainer:   Torsten Kurbad
# Copyright:    (c) 2008 iwm-kmrc.de KMRC - Knowledge Media Research Center
# Licence:      GPL
#############################################################################
"""KAdm5 Adapter exceptions.
"""

class RealmNotConfigured(Exception):
    """ The realm parameters cannot be found in /etc/krb5.conf. """

class ClientNotFound(Exception):
    """ The client principal does not exist. """

class IncorrectPassword(Exception):
    """ The client password is wrong. """

class PrincipalAlreadyExists(Exception):
    """ The principal does already exist. """

class PrincipalNotFound(Exception):
    """ The principal does not exist. """

class BadServerHandle(Exception):
    """ The server handle is not valid. """

class KAdm5GenericException(Exception):
    """ A generic Exception for all other errors. """

def throwException(error):
    """ Re-raise exception error to make Exception handling easier. """
    e = "%s" % error
    if e.endswith("Missing parameters in krb5.conf required for kadmin client"):
        raise RealmNotConfigured
    elif e.endswith("Client not found in Kerberos database"):
        raise ClientNotFound
    elif e.endswith("Incorrect password"):
        raise IncorrectPassword
    elif e.endswith("Principal or policy already exists"):
        raise PrincipalAlreadyExists
    elif e.endswith("Principal does not exist"):
        raise PrincipalNotFound
    elif e.endswith("Programmer error! Bad Admin server handle"):
        raise BadServerHandle
    else:
        raise KAdm5GenericException
