#!/usr/local/env python
#############################################################################
# Name:         interfaces.py
# Purpose:      Kerberos5 admin service adapter interface
# Maintainer:   Torsten Kurbad
# Copyright:    (c) 2008 iwm-kmrc.de KMRC - Knowledge Media Research Center
# Licence:      GPL
#############################################################################
"""KAdm5 Adapter interfaces.
"""

import zope.interface
from zope.schema import Bool, Password, TextLine

from i18n import MessageFactory as _


class IKAdm5Adapter(zope.interface.Interface):
    """ Adapter to a Kerberos5 admin server. """
    client = TextLine(
        title=_(u'Kerberos5 admin principal'),
        default=u'root/admin',
        required=True,
        )
    password = Password(
        title=_(u'Kerberos5 admin password'),
        default=u'',
        required=True,
        )
    realm = TextLine(
        title=_(u'Kerberos5 Realm'),
        default=u'',
        required=True,
        )

    def kconnect(client=None, password=None, realm=None):
        """ Connect to the server and return an IKAdm5Connection.
            May raise exceptions from the underlying kadm5 module.
        """
 


class IKAdm5Connection(zope.interface.Interface):
    """ Connection to a Kerberos5 admin server."""

    def getPrincipals():
        """ Get a list of all principals registered with the connected
            Kerberos admin server.
        """

    def existPrincipal(princ):
        """ Check for existance of a specific principal princ. """

    def createPrincipal(princ, password):
        """ Create a new principal princ with the given password. """

    def deletePrincipal(princ):
        """ Delete principal princ. """

    def chpassPrincipal(princ, new_password):
        """ Change principal princ's password to new_password. """

    def destroy():
        """ Close the connection to the Kerberos admin server. """


class ICheckKAdm5Adapter(zope.interface.Interface):
    """ A test adapter for to test the connection from Zope to KAdmin. """

    def testConnection():
        """ Test the KAdmin connection. Returns "Success!" or "Failure!" """
