#!/usr/local/env python
#############################################################################
# Name:         fakekadm5.py
# Purpose:      Kerberos5 admin server adapter utility test suite
# Maintainer:   Torsten Kurbad
# Copyright:    (c) 2008 iwm-kmrc.de KMRC - Knowledge Media Research Center
# Licence:      GPL
#############################################################################
"""Fake KAdm5 module to test simple functionality.
"""

class Error(Exception):
    """ Exception fake. """

class connection(object):
    def __init__(self, realm):
        self.connection = False
        self.realm = realm
        self.principals = ['root/admin@TEST.COM']

    def _canonize(self, princ):
        if '@' in princ:
            return princ
        else:
            return "%s@%s" % (princ, self.realm)

    
def kadm5_init(client, password, realm):
    if (client, password, realm) == ('root/admin', 'test', 'TEST.COM'):
        conn = connection(realm)
        conn.connection = True
        return conn
    elif realm != 'TEST.COM':
        raise  Error, "kadm5_init_with_password(): Missing parameters in krb5.conf required for kadmin client"
    elif client != 'root/admin':
        raise Error, "kadm5_init_with_password(): Client not found in Kerberos database"
    elif (client == 'root/admin') and password != 'test':
        raise Error, "kadm5_init_with_password(): Incorrect password"
    
def kadm5_get_principals(conn):
    if conn and conn.connection:
        return conn.principals

def kadm5_exist_principal(conn, principal):
    if conn and conn.connection:
        principal = conn._canonize(principal)

        if principal in conn.principals:
            return True
        else:
            return False

def kadm5_create_principal(conn, principal, password):
    if conn and conn.connection:
        principal = conn._canonize(principal)

        if principal not in conn.principals:
            conn.principals.append(principal)
            conn.principals.sort()
            return 0
        else:
            raise Error, "kadm5_create_principal(): Principal or policy already exists"

def kadm5_delete_principal(conn, principal):
    if conn and conn.connection:
        principal = conn._canonize(principal)

        if principal in conn.principals:
            conn.principals.remove(principal)
            return 0
        else:
            raise Error, "kadm5_delete_principal(): Principal does not exist"

def kadm5_chpass_principal(conn, principal, password):
    if conn and conn.connection:
        principal = conn._canonize(principal)

        if principal in conn.principals:
            return 0
        else:
            raise Error, "kadm5_chpass_principal(): Principal does not exist"

def kadm5_destroy(conn):
    if conn and conn.connection:
        conn.connection = False
        return 0
    else:
        raise Error, "kadm5_init_with_password(): Programmer error! Bad Admin server handle"
