#!/usr/local/env python
#############################################################################
# Name:         check.py
# Purpose:      Kerberos5 admin server adapter utility
# Maintainer:   Torsten Kurbad
# Copyright:    (c) 2008 iwm-kmrc.de KMRC - Knowledge Media Research Center
# Licence:      GPL
#############################################################################
"""KAdm5 Adapter.
"""
import re
import kadm5
import persistent
import zope.interface
from zope.app.container.contained import Contained
from zope.app.component.vocabulary import UtilityVocabulary
from zope.schema.fieldproperty import FieldProperty

from kadm5adapter import interfaces
from kadm5adapter import exceptions

def valuesToUTF8(values):
    return [v.encode('utf-8') for v in values]


class KAdm5Adapter(persistent.Persistent):
    """ Adapter to a Kerberos5 admin server. """
    zope.interface.implements(interfaces.IKAdm5Adapter)

    client = FieldProperty(interfaces.IKAdm5Adapter['client'])
    password = FieldProperty(interfaces.IKAdm5Adapter['password'])
    realm = FieldProperty(interfaces.IKAdm5Adapter['realm'])    


    def __init__(self, client=None, password=None, realm=None):
        if client is not None:
            self.client = client
        if password is not None:
            self.password = password
        if realm is not None:
            self.realm = realm

    def kconnect(self, client=None, password=None, realm=None):
        """ Connect to the server and return a KAdm5Connection.
            May raise exceptions from the underlying kadm5 module.
        """
        if client is None:
            client = self.client
            password = self.password
        if realm is None:
            realm = self.realm

        try:
            conn = kadm5.kadm5_init(client, password, realm)
        except kadm5.Error, e:
            exceptions.throwException(e)

        if conn is not None:
            return KAdm5Connection(conn)
        else:
            return None


class KAdm5Connection(object):
    """ Connection to a Kerberos5 admin server."""
    zope.interface.implements(interfaces.IKAdm5Connection)

    def __init__(self, conn):
        self.conn = conn

    def getPrincipals(self):
        """ Get a list of all principals registered with the connected
            Kerberos admin server.
        """
        try:
            return kadm5.kadm5_get_principals(self.conn)
        except kadm5.Error, e:
            exceptions.throwException(e)

    def existPrincipal(self, princ):
        """ Check for existance of a specific principal princ. """
        try:
            return kadm5.kadm5_exist_principal(self.conn, princ)
        except kadm5.Error, e:
            exceptions.throwException(e)

    def createPrincipal(self, princ, password):
        """ Create a new principal princ with the given password. """
        try:
            return kadm5.kadm5_create_principal(self.conn, princ, password)
        except kadm5.Error, e:
            exceptions.throwException(e)

    def deletePrincipal(self, princ):
        """ Delete principal princ. """
        try:
            return kadm5.kadm5_delete_principal(self.conn, princ)
        except kadm5.Error, e:
            exceptions.throwException(e)

    def chpassPrincipal(self, princ, new_password):
        """ Change principal princ's password to new_password. """
        try:
            return kadm5.kadm5_chpass_principal(self.conn, princ, new_password)
        except kadm5.Error, e:
            exceptions.throwException(e)

    def destroy(self):
        """ Close the connection to the Kerberos admin server. """
        try:
            return kadm5.kadm5_destroy(self.conn)
        except kadm5.Error, e:
            exceptions.throwException(e)


class KAdm5AdapterVocabulary(UtilityVocabulary):
    """ Vocabulary for utility registration. """
    interface = interfaces.IKAdm5Adapter
    nameOnly = True
